.. _braginskii:

************************************************************
Classical transport theory (`plasmapy.formulary.braginskii`)
************************************************************

.. currentmodule:: plasmapy.formulary.braginskii

.. automodapi:: plasmapy.formulary.braginskii

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/braginskii
